@@ -25,7 +25,22 @@
 
 G_BEGIN_DECLS
 
+#define GST_TYPE_FFMPEGVIDDEC           (gst_ffmpegviddec_get_type())
+#define GST_FFMPEGVIDDEC(obj)           (G_TYPE_CHECK_INSTANCE_CAST((obj),GST_TYPE_FFMPEGVIDDEC,GstFFMpegVidDec))
+#define GST_FFMPEGVIDDEC_CLASS(klass)   (G_TYPE_CHECK_CLASS_CAST((klass),GST_TYPE_FFMPEGVIDDEC,GstFFMpegVidDecClass))
+#define GST_FFMPEGVIDDEC_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GST_TYPE_FFMPEGVIDDEC, GstFFMpegVidDecClass))
+#define GST_IS_FFMPEGVIDDEC(obj)        (G_TYPE_CHECK_INSTANCE_TYPE((obj),GST_TYPE_FFMPEGVIDDEC))
+#define GST_IS_FFMPEGVIDDEC_CLASS(obj)  (G_TYPE_CHECK_CLASS_TYPE((klass),GST_TYPE_FFMPEGVIDDEC))
+
+/**
+ * GstFFMpegVidDec:
+ *
+ * The #GstFFMpegVidDec data structure.
+ *
+ * Since: 1.22
+ */
 typedef struct _GstFFMpegVidDec GstFFMpegVidDec;
+
 struct _GstFFMpegVidDec
 {
   GstVideoDecoder parent;
@@ -39,7 +54,6 @@ struct _GstFFMpegVidDec
   GstVideoMultiviewMode picture_multiview_mode;
   GstVideoMultiviewFlags picture_multiview_flags;
   gint stride[AV_NUM_DATA_POINTERS];
-  gboolean opened;
 
   /* current output pictures */
   enum AVPixelFormat pic_pix_fmt;
@@ -66,10 +80,10 @@ struct _GstFFMpegVidDec
   enum AVDiscard skip_frame;
   gint lowres;
   gboolean direct_rendering;
-  gboolean debug_mv;
   int max_threads;
   gboolean output_corrupt;
   guint thread_type;
+  GstAvCodecCompliance std_compliance;
 
   GstCaps *last_caps;
 
@@ -79,6 +93,8 @@ struct _GstFFMpegVidDec
   gint pool_height;
   enum AVPixelFormat pool_format;
   GstVideoInfo pool_info;
+
+  gboolean needs_renegotation;
 };
 
 typedef struct _GstFFMpegVidDecClass GstFFMpegVidDecClass;
@@ -87,9 +103,11 @@ struct _GstFFMpegVidDecClass
 {
   GstVideoDecoderClass parent_class;
 
-  AVCodec *in_plugin;
+  const AVCodec *in_plugin;
 };
 
+GType gst_ffmpegviddec_get_type (void);
+
 G_END_DECLS
 
 #endif
